@@ -28,6 +28,13 @@ iSqlPathList = List[Union[str, os.PathLike, Path]]
 
 class iSqlDF(pl.DataFrame):
     def __rich_repr__(self) -> rich.table.Table:
+        records = orjson.loads(self.write_json(row_oriented=True))
+        return tableFromRecords(records, theme="default").__rich_console__()
+    def __rich_console__(self) -> rich.table.Table:
+        records = orjson.loads(self.write_json(row_oriented=True))
+        return tableFromRecords(records, theme="default").__rich_console__()
+    
+    def asRichTable(self):
         records = orjson.loads(self.write_json(row_oriented=True))
         return tableFromRecords(records, theme="default")
 
